<?php

namespace translate\websitetranslator\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\config\config */
	protected $config;
	/** @var \phpbb\template\template */
	protected $template;
	/** @var \phpbb\user */
	protected $user;

	public function __construct(\phpbb\config\config $config, \phpbb\template\template $template, \phpbb\user $user)
	{
		$this->config = $config;
		$this->template = $template;
		$this->user = $user;
	}

	
	static public function getSubscribedEvents()
	{
		return array(
			'core.acp_board_config_edit_add'	=> 'add_websitetranslator_configs',
			'core.page_header'			=> 'load_websitetranslator',
			'core.validate_config_variable'		=> 'validate_websitetranslator_id',
		);
	}

	public function load_websitetranslator()
	{
		//convert bool to string
		$this->config['guess_language'] = ($this->config['guess_language']) ? 'true' : 'false';
		$this->config['remember_language'] = ($this->config['remember_language']) ? 'true' : 'false';
		$this->config['translate_meta']	= ($this->config['translate_meta']) ? 'true' : 'false';
		$this->config['localize_images'] = ($this->config['localize_images']) ? 'true' : 'false';
		$this->config['localize_bg_images'] = ($this->config['localize_bg_images']) ? 'true' : 'false';
		$this->config['localize_media']	= ($this->config['localize_media']) ? 'true' : 'false';

		$translator_id = $this->config['websitetranslator_id'];
    //$translator_id = addslashes($translator_id);

		//assign variables and load variables
		$this->template->assign_vars(array(
			'WEBSITETRANSLATOR_ID' => $translator_id, 
			'GUESS_LANGUAGE' => $this->config['guess_language'],
			'REMEMBER_LANGUAGE' => $this->config['remember_language'],
               		'TRANSLATE_META' => $this->config['translate_meta'],
                	'LOCALIZE_IMAGES' => $this->config['localize_images'],
                	'LOCALIZE_BG_IMAGES' => $this->config['localize_bg_images'],
			'LOCALIZE_MEDIA' => $this->config['localize_media'],
			)
		);
	}
	
	public function add_websitetranslator_configs($event)
	{
		// Load language file
		$this->user->add_lang_ext('translate/websitetranslator', 'websitetranslator_acp');


		// Add a config to the settings mode, after board_timezone
		if ($event['mode'] == 'settings' && isset($event['display_vars']['vars']['board_timezone']))
		{
			// Store display_vars event in a local variable
			$display_vars = $event['display_vars'];
			// Define the new config vars
			$wt_config_vars = array(
				'websitetranslator_id' => array(
					'lang' => 'ACP_WEBSITETRANSLATOR_ID',
					'validate' => 'websitetranslator_id',
					'type' => 'text:40:20',
					'explain' => false,
				),

				'remember_language' => array(
					'lang' => 'ACP_REMEMBER_LANGUAGE',
					'validate' => 'bool',
					'type' => 'radio:yes_no',
					'explain' => false,
				),
				
				'guess_language' => array(
                                        'lang' => 'ACP_GUESS_LANGUAGE',
                                        'validate' => 'bool',
                                        'type' => 'radio:yes_no',
                                        'explain' => false,
                                ),

				'translate_meta' => array(
                                        'lang' => 'ACP_TRANSLATE_META',
                                        'validate' => 'bool',
                                        'type' => 'radio:yes_no',
                                        'explain' => false,
                                ),

				'localize_images' => array(
                                        'lang' => 'ACP_LOCALIZE_IMAGES',
                                        'validate' => 'bool',
                                        'type' => 'radio:yes_no',
                                        'explain' => false,
                                ),

				'localize_bg_images' => array(
                                        'lang' => 'ACP_LOCALIZE_BG_IMAGES',
                                        'validate' => 'bool',
                                        'type' => 'radio:yes_no',
                                        'explain' => false,
                                ),

				'localize_media' => array(
                                        'lang' => 'ACP_LOCALIZE_MEDIA',
                                        'validate' => 'localize_media',
                                        'type' => 'radio:yes_no',
                                        'explain' => false,
                                ),

			);
			// Add the new config vars after board_timezone in the display_vars config array
			$insert_after = array('after' => 'board_timezone');
			$display_vars['vars'] = phpbb_insert_config_array($display_vars['vars'], $wt_config_vars, $insert_after);
			// Update the display_vars event with the new array
			$event['display_vars'] = $display_vars;
		}
	}

	public function validate_websitetranslator_id($event)
	{
		$input = $event['cfg_array']['websitetranslator_id'];
		
		// Check if the validate test is for google_analytics
		if (($event['config_definition']['validate'] == 'websitetranslator_id') && ($input !== ''))
		{
			// Store the error and input event data
			$error = $event['error'];

			// Add error message if the input is not a valid website translator ID
			// Update error event data
			$event['error'] = $error;
		}
	}
}
